#!/bin/sh

# -----------------------------------------------------------
# IBM Confidential
# 
# DOORS - %full_filespec: common.sh~10:shsrc:ERS#1 %  %date_created: Thu Jul 10 13:46:59 2008 %
#
# (c) Copyright IBM Corporation 1993, 2008. All Rights Reserved.
# -----------------------------------------------------------

check_version()
{

    cdverfile="${cdrompath}""/""`echo version.txt | eval $fnc`"
    verfile="${installpath}""/version.txt"
    if [ -r "${verfile}" ] ; then
	verdata="v"`cat "${verfile}"`
	cdverdata="v"`cat "${cdverfile}"`
        if [ "${verdata}" = "${cdverdata}" ] ; then
	    sameversion="y"
    	fi
    fi
}

set_version()
{

    cdverfile=$cdrompath"/""`echo version.txt | eval $fnc`"
    verfile=$installpath"/version.txt"
    rm -f $verfile 2>> /tmp/doorslog
    cp $cdverfile $verfile 2>> /tmp/doorslog
}

get_data_install()
{
    exampledatatar=$cdrompath"/""`echo doors/common/doc/example_database/example_database.tar | eval $fnc`"

    if [ ! -r $exampledatatar ] ; then
        install_data="n"
        return 0
    fi

    $echocmd -n "Install the demo database [n] :"
    read install_data

    if [ "${install_data}" = "" ] ; then
	install_data="n"
    fi
    if [ "${install_data}" = "n" ] ; then
        return 0
    fi

    defdatapath=$installpath"/data"

    $echocmd -n "Enter path to install database [" $defdatapath "] :"
    read datapath

    if [ "$datapath" = "" ] ; then
	datapath=$defdatapath
    fi
    if [ ! -d $datapath ] ; then
	if [ -d `dirname $datapath` -a -w `dirname $datapath` ] ; then
            mkdir $datapath
	else
            $echocmd $datapath " does not exist and cannot be created!"
	    exit 1
	fi
    else
	$echocmd $datapath " already exits and will not be overwritten."
	install_data="n"
	return 0
    fi
    if [ ! -w $datapath ] ; then
        $echocmd $datapath " is not writable!"
	exit 1
    fi
}

get_install_path()
{
    if [ "$DOORSNET_INSTALL" != "1" ] ; then
       $echocmd -n "Enter path to install "$1" [" $defdestpath "]: "
       read installpath
    else
       installpath="" # i.e. use default
    fi

    if [ "${installpath}" = "" ] ; then
	installpath=$defdestpath
    fi
    if [ "${installpath}" = "${cdrompath}" ] ; then 
        $echocmd "install path" $installpath "and CDROM/distribution path" $cdrompath "should not be the same!"
	exit 1
    fi
    if [ ! -d "${installpath}" ] ; then
	if [ -d `dirname $installpath` -a -w `dirname $installpath` ] ; then
            mkdir $installpath
	else
            $echocmd $installpath " does not exist and cannot be created!"
	    exit 1
	fi
    fi
    if [ ! -w "${installpath}" ] ; then
        $echocmd $installpath " is not writable!"
	exit 1
    fi
}


get_doors_user()
{
    if [ "$DOORSNET_INSTALL" = "1" ] ; then
       $echocmd -n "Enter the name of the Telelogic DOORSnet owner [doors]: "
    else
       $echocmd -n "Enter the name of the Telelogic DOORS owner [doors]: "
    fi
    read username
    if [ "$username" = "" ] ; then
	username="doors"
    fi
}

install_doors_data() 
{ 
    if [ "${username}" = "" ] ; then
	echo "The Telelogic DOORS admin user cannot be determined."
        ehco "Unable to install the demo database."
        exit 1
    fi

    echo "Extracting demo database from tar file"
    (cd $datapath; tar xf $installpath/training/example_database.tar)
    echo "Setting permissions on the demo database"

    chown -R $username $datapath
    chmod -R u=rwX,og-rwx $datapath
}

move_directory()
{
    if [ -d $1 ] ; then
        i=1
        while [ -d $1"_"$i ] ; do
            i=`expr $i + 1`
        done
        mv $1 $1"_"$i 2>> /tmp/doorslog
    fi
}    

update_version() 
{
   cdverfile=$cdrompath"/""`echo version | eval $fnc`"
   verfile=$install"/version"

   if [ -r "${verfile}" ] ; then
       rm -f "${verfile}" 2>> /tmp/doorslog
   fi

   cp "${cdverfile}" "${verfile}" 2>> /tmp/doorslog
}

hpecho()
{
    if [ "X$1" = "X-n" ] ; then
        shift
        printf "%s" "$*"
    else
        printf "%s\n" "$*"
    fi
}


get_echocmd()
{
sys_name=`uname -s`
sys_release=`uname -r`
 
    if [ "${sys_name}" = "HP-UX" ] ; then
        echocmd="hpecho" 
    fi
    if [ "${sys_name}" = "SunOS" ] ; then
        case $sys_release in
                5*)
                    echocmd="/usr/ucb/echo" ;;
                *)
        esac
    fi
}

get_cmds()
{
    case $thisarch in
      hpux )
	dfcmd="/usr/bin/bdf"
        ;;
      alpha)
	dfcmd="/bin/df -k"
        ;;
      aix)
        dfcmd="/bin/df -I"
        ;;
      sunos )
	dfcmd="/usr/bin/df"
        ;;
      solaris )
        echocmd="/usr/ucb/echo"
	dfcmd="/bin/df -k"
        ;;
    esac
}

print_banner()
{
    clear
    $echocmd "Telelogic DOORS"
    $echocmd "Software installation"
}

set_perm() 
{
    if [ -d $1 ] ; then
        chown -R $username $1 2>> /tmp/doorslog 
    fi
}
set_perms()
{
    if [ "$DOORSNET_INSTALL" = "1" ] ; then
       $echocmd -n "Setting base file permissions..."
    else
       $echocmd "Setting file permissions"
    fi

    set_perm $installpath/bin
    set_perm $installpath/etc
    set_perm $installpath/lib
    set_perm $installpath/example
    set_perm $installpath/api
    set_perm $installpath/include
    set_perm $installpath/training
    set_perm $installpath/mw
    set_perm $installpath/sms
    set_perm $installpath/help

    chown $username $installpath 2>> /tmp/doorslog

    if [ "${install_data}" = "y" ] ; then
        $echocmd "Setting database file permissions"
	set_perm $datapath
    fi
    chmod -R 755 bin lib etc  2>> /tmp/doorslog

    find $installpath/bin -name "doorsd" -type f -exec chmod u+s {} ";" 2>> /tmp/doorslog

    if [ "$DOORSNET_INSTALL" = "1" ] ; then
       $echocmd done
    fi
}



