#!/bin/sh
#
# Telelogic DOORS Installation script
#

# -----------------------------------------------------------
# IBM Confidential
# 
# DOORS - %full_filespec: instdoor.sh~17:shsrc:ERS#1 %  %date_created: Mon Sep 22 15:42:19 2008 %
#
# (c) Copyright IBM Corporation 1993, 2008. All Rights Reserved.
# -----------------------------------------------------------

defcdpath=""
defdestpath="/users/doors"
defdatapath="/users/doors/data"
datapath=""
cdrompath=""
installpath=""
installdata="n"
username=""
archs=""
instcommon="n"
echocmd="echo"
dfcmd="df"
if [ "$1" = "DOORSNET_INSTALL" ] ; then
   DOORSNET_INSTALL="1"
fi

get_exepath()
{
   if [ "v"`echo $1 | awk '{ print substr ($1,1,1) }'` = "v/" ] ; then
       exepath=`dirname $1`
   else
       tcurpath=`pwd`
       cd `pwd`"/"`dirname $1`
       exepath=`pwd`
       cd $tcurpath
   fi
   exepath=`dirname $exepath`
   exepath=`dirname $exepath`

}

get_fnc()
{
    if [ `basename $0` = "instdoor.sh" ] ; then
	fnc="cat -"
	pnc="cat -"
    else 
	fnc="sed -e 's/$/;1/' | tr \"[:lower:]\" \"[:upper:]\""
	pnc="tr \"[:lower:]\" \"[:upper:]\""
   fi
}

altecho()
{
    if [ "X$1" = "X-n" ] ; then
        shift
        printf "%s" "$*"
    else
        printf "%s\n" "$*"
    fi
}


get_echocmd()
{
sys_name=`uname -s`
sys_release=`uname -r`
 
    if [ "${sys_name}" = "HP-UX" ] ; then
        echocmd="altecho" 
    fi
    if [ "${sys_name}" = "AIX" ] ; then
        echocmd="altecho" 
    fi
    
    if [ "${sys_name}" = "SunOS" ] ; then
        case $sys_release in
                5*)
                    echocmd="/usr/ucb/echo" ;;
                *)
        esac
    fi
    if [ "${sys_name}" = "Linux" ] ; then
	echocmd="/bin/echo"
    fi
}


print_banner()
{
    clear
    $echocmd "Telelogic DOORS"
    $echocmd "Software installation"
}

print_license()
{
    $echocmd ""
    cat $cdrompath/unix/bin/EULA.txt
    $echocmd ""
    $echocmd -n "Press return to continue..."
    read resp
    $echocmd ""
}

print_install()
{
    $echocmd ""
    $echocmd "Please ensure that you"
    $echocmd "- Run the installation as root"
    $echocmd "- Have created a home directory for the Telelogic DOORS installation"
    $echocmd "- Have created a non-privileged account to own the Telelogic DOORS files"
    $echocmd "  We recommend that you call this user 'doors'"
    $echocmd ""
    $echocmd "See the installation manual for further details"
    $echocmd ""  
}

explain_DOORS_INTEROP()
{
    $echocmd ""
    $echocmd "DOORS_INTEROP. Installs the Telelogic DOORS interop server"
 }

explain_DOORS_SERVER()
{
    $echocmd ""
    $echocmd "DOORS_SERVER. Installs the Telelogic DOORS database server"
}

#explain_FLEX_SERVER()
#{
#    $echocmd ""
#    $echocmd "FLEX_SERVER. Installs the FLEXlm license server"
#}

get_cdrom_path()
{
    if [ "$DOORSNET_INSTALL" = "1" ] ; then
       cdrompath="" # i.e. just use default
    else
       clear
       print_banner
       print_install
       $echocmd -n "Enter path to CDROM device or Telelogic DOORS distribution [" $defcdpath "]: "
       read cdrompath
    fi

    if [ "$cdrompath" = "" ] ; then
	cdrompath=$defcdpath
    fi

    if [ ! -d $cdrompath ] ; then
        $echocmd $cdrompath " is not a directory!"
	exit 1
    fi
    if [ ! -r $cdrompath ] ; then
        $echocmd $cdrompath " is not readable!"
	exit 1
    fi
    if [ `echo $cdrompath | awk '{ print substr($1,1,1) }'` != "/" ] ; then
	cdrompath=`pwd`/$cdrompath
    fi
    
    if [ "$DOORSNET_INSTALL" != "1" ] ; then
       print_license
    fi
}

get_packages()
{
    pkgfile=$cdrompath/`echo packages.txt | eval $fnc`
    availpackages=`cat $pkgfile | awk ' { print $1 }'`
    packagepaths=`cat $pkgfile | awk ' { print $2 }'`

    if [ "$DOORSNET_INSTALL" != "1" ] ; then
       print_banner
       $echocmd -n "Select package to install [ "

       for pack in $availpackages
       do
	   $echocmd -n $pack " "
       done
       $echocmd " ]"
    
       for pack in $availpackages
       do
	   explain_$pack
       done
    fi
    # else don't allow user to select packages - install defaults

    def="y"
    packs=""
    if [ "$DOORSNET_INSTALL" != "1" ] ; then
       echo
    fi

    for pack in $availpackages
    do
        if [ "${packs}" = "" ] ; then 
            if [ "$DOORSNET_INSTALL" = "1" ] ; then
               resp="" # i.e. just use default
            else
               $echocmd -n "Install package " ${pack} " [" ${def} "]: "
	       read resp
            fi
    	    if [ "${resp}" = "" ] ; then
		resp=$def
            fi
	    if [ "${resp}" = "y" ] ; then
		packs=${packs}" "${pack}
	    fi
        fi
    done

}
install_packs()
{
   i="2"
   for allpacks in $availpackages
   do
       for pack in $packs
       do
	   if [ "${allpacks}" = "${pack}" ] ; then
	       commnd=`echo $i $packagepaths | awk '{ i=$1 ; print $i }'`
	       commnd=`echo $commnd | eval $fnc` 
               if [ "$DOORSNET_INSTALL" != "1" ] ; then
                  sh $cdrompath/$commnd $cdrompath
                  $echocmd ""
                  $echocmd -n "Package" $pack "script completed, press return to continue..."
	          read resp
               else
                  sh $cdrompath/$commnd $cdrompath DOORSNET_INSTALL 
               fi
	   fi
       done
       i=`expr $i + 1`
   done		
}


get_echocmd
get_exepath $0
defcdpath=$exepath
get_cdrom_path
get_fnc
get_packages
install_packs
exit 0
